Prelude to use essentials: use my_module ::prelude :: *.
Macros
- debug_
assert_ id - Macro asserts that two expressions are identical to each other. Unlike
std ::assert_eqit is removed from a release build. - debug_
assert_ identical - Macro asserts that two expressions are identical to each other. Unlike
std ::assert_eqit is removed from a release build. Alias ofdebug_assert_id. - debug_
assert_ ni - Macro asserts that two expressions are not identical to each other. Unlike
std ::assert_eqit is removed from a release build. - debug_
assert_ not_ identical - Macro asserts that two expressions are not identical to each other. Unlike
std ::assert_eqit is removed from a release build.